==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-angular-core";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Base, Number_$type, typeCast, fromEnum, Point_$type, markType, markDep, runOn } from "igniteui-angular-core";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_, truncate } from "igniteui-angular-core";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-angular-core";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var CategoryHighlightLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.hm / 1000;
        _this.p6 = a;
        _this.p5 = b;
        _this.p7 = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.get_db = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.bx = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.q9 = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "rc", {
        get: function () {
            return this.c(CategoryHighlightLayer.rj);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.rj, a);
        },
        enumerable: false,
        configurable: true
    });
    CategoryHighlightLayer.prototype.qo = function (a, b) {
        if (this.q8 == null || this.q8 == a) {
            if (!this.as.c) {
                this.mi(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.ra = function (a) {
        return a != null && a.cn();
    };
    CategoryHighlightLayer.prototype.qr = function (a, b) {
        var e_1, _a;
        _super.prototype.qr.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.rb;
        if (isNaN_(this.q5.x) && isNaN_(this.q5.y)) {
            return;
        }
        if (this.q8 != null) {
            if (this.ra(this.q8)) {
                this.rh(this.q8, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.cd) !== null) {
                var e = this.cd;
                try {
                    for (var _b = __values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.ra(f)) {
                            this.rh(f, c, d);
                        }
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.rh = function (a, b, c) {
        if (this.b0 == null || this.b0.bv.isEmpty || this.b0.bu.isEmpty) {
            return;
        }
        var d = this.q5.x;
        if (a.co && isNaN_(d)) {
            d = 0;
        }
        var e = this.pr(this.b0);
        d = e.left + e.width * (d - this.b0.bv.left) / this.b0.bv.width;
        var f = this.q5.y;
        if (!a.co && isNaN_(f)) {
            f = 0;
        }
        f = e.top + e.height * (f - this.b0.bv.top) / this.b0.bv.height;
        var g = a.md({ $type: Point_$type, x: d, y: f }, c, this.rc);
        this.rg(g, b, a);
    };
    CategoryHighlightLayer.prototype.rg = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.q3();
        d.h = this.q4();
        if (d.g == null) {
            d.g = this.q9.cc(c.ju);
        }
        if (d.h == null) {
            d.h = this.q9.cc(c.ju);
        }
        d.d = this.fu;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.qu = function (a, b) {
        var e_2, _a;
        _super.prototype.qu.call(this, a, b);
        var c = this.q9.b5;
        var d = a;
        var e = 0;
        try {
            for (var _b = __values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.ri(f, g);
                e++;
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.em = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.ri = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.q9.b7(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.pc != null) {
            b.ai = this.pc;
        }
        else {
            b.ai = null;
        }
        b.ad = this.pd;
    };
    CategoryHighlightLayer.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.mi(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.mi(true);
                break;
        }
    };
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    CategoryHighlightLayer.rj = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    CategoryHighlightLayer.$$p = markDep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:q8:rk', [CategoryAxisBase.$, null], 'UseInterpolation:rb:rl', [0, false]]);
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
/**
 * @hidden
 */
var CategoryHighlightLayerView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.b4 = null;
        _this.b5 = null;
        _this.b6 = null;
        _this.b4 = a;
        _this.b6 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.as = function () {
        var _this = this;
        _super.prototype.as.call(this);
        this.b5 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.cd);
            $ret.activate = runOn(_this, _this.b8);
            $ret.disactivate = runOn(_this, _this.ca);
            $ret.destroy = runOn(_this, _this.b9);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.cd = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b6.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b8 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.ca = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b9 = function (a) {
        this.b6.remove(a);
    };
    CategoryHighlightLayerView.prototype.cb = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.l(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.cc = function (a) {
        if (a != null) {
            var b = BrushUtil.l(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b7 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b6.count; c++) {
                var d = this.b6._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        for (var b = 0; b < this.b6.count; b++) {
            this.e.a8.exportRectangleData(a, this.b6._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };

==> igniteui-angular-charts-14.2.0.tgz: package/esm5/lib/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-angular-core";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Base, Number_$type, typeCast, fromEnum, Point_$type, markType, markDep, runOn } from "igniteui-angular-core";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-angular-core";
import { Pool$1 } from "igniteui-angular-core";
import { Rectangle } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_, truncate } from "igniteui-angular-core";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-angular-core";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var CategoryHighlightLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.ho / 1000;
        _this.qa = a;
        _this.p9 = b;
        _this.qb = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.get_db = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.bx = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.rd = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "rg", {
        get: function () {
            return this.c(CategoryHighlightLayer.rn);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.rn, a);
        },
        enumerable: false,
        configurable: true
    });
    CategoryHighlightLayer.prototype.qs = function (a, b) {
        if (this.rc == null || this.rc == a) {
            if (!this.as.c) {
                this.ml(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.re = function (a) {
        return a != null && a.cn();
    };
    CategoryHighlightLayer.prototype.qv = function (a, b) {
        var e_1, _a;
        _super.prototype.qv.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.rf;
        if (isNaN_(this.q9.x) && isNaN_(this.q9.y)) {
            return;
        }
        if (this.rc != null) {
            if (this.re(this.rc)) {
                this.rl(this.rc, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.cd) !== null) {
                var e = this.cd;
                try {
                    for (var _b = __values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.re(f)) {
                            this.rl(f, c, d);
                        }
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.rl = function (a, b, c) {
        if (this.b0 == null || this.b0.bv.isEmpty || this.b0.bu.isEmpty) {
            return;
        }
        var d = this.q9.x;
        if (a.co && isNaN_(d)) {
            d = 0;
        }
        var e = this.pv(this.b0);
        d = e.left + e.width * (d - this.b0.bv.left) / this.b0.bv.width;
        var f = this.q9.y;
        if (!a.co && isNaN_(f)) {
            f = 0;
        }
        f = e.top + e.height * (f - this.b0.bv.top) / this.b0.bv.height;
        var g = a.md({ $type: Point_$type, x: d, y: f }, c, this.rg);
        this.rk(g, b, a);
    };
    CategoryHighlightLayer.prototype.rk = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.q7();
        d.h = this.q8();
        if (d.g == null) {
            d.g = this.rd.cc(c.ju);
        }
        if (d.h == null) {
            d.h = this.rd.cc(c.ju);
        }
        d.d = this.fw;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.qy = function (a, b) {
        var e_2, _a;
        _super.prototype.qy.call(this, a, b);
        var c = this.rd.b5;
        var d = a;
        var e = 0;
        try {
            for (var _b = __values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.rm(f, g);
                e++;
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.en = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.rm = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.rd.b7(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.pg != null) {
            b.ai = this.pg;
        }
        else {
            b.ai = null;
        }
        b.ad = this.ph;
    };
    CategoryHighlightLayer.prototype.l7 = function (a, b, c, d) {
        _super.prototype.l7.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.ml(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.ml(true);
                break;
        }
    };
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    CategoryHighlightLayer.rn = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    CategoryHighlightLayer.$$p = markDep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:rc:ro', [CategoryAxisBase.$, null], 'UseInterpolation:rf:rp', [0, false]]);
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
/**
 * @hidden
 */
var CategoryHighlightLayerView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.b4 = null;
        _this.b5 = null;
        _this.b6 = null;
        _this.b4 = a;
        _this.b6 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.as = function () {
        var _this = this;
        _super.prototype.as.call(this);
        this.b5 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.cd);
            $ret.activate = runOn(_this, _this.b8);
            $ret.disactivate = runOn(_this, _this.ca);
            $ret.destroy = runOn(_this, _this.b9);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.cd = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b6.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b8 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.ca = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b9 = function (a) {
        this.b6.remove(a);
    };
    CategoryHighlightLayerView.prototype.cb = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.l(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.cc = function (a) {
        if (a != null) {
            var b = BrushUtil.l(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b7 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b6.count; c++) {
                var d = this.b6._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        for (var b = 0; b < this.b6.count; b++) {
            this.e.a8.exportRectangleData(a, this.b6._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };
